[![Tests](https://github.com/andridns/hypermodern-py/workflows/Tests/badge.svg)](https://github.com/andridns/hypermodern-py/actions?workflow=Tests)

[![codecov](https://codecov.io/gh/andridns/hypermodern-py/branch/main/graph/badge.svg?token=16D51BG5O3)](https://codecov.io/gh/andridns/hypermodern-py)

[![PyPI](https://img.shields.io/pypi/v/hypermodern-py.svg)](https://pypi.org/project/hypermodern-py/)

# hypermodern-py

My hypermodern python project.
